@@ -1,16 +1,21 @@
 pub(crate) mod line_column;
 #[cfg(feature = "lsp-types")]
 pub(crate) mod lsp;
-pub(crate) mod text_change;
 pub(crate) mod text_indexed;
 
 #[cfg(test)]
 mod test;
 
-use crate::CSTNode;
+use crate::{Result, TextAdaptor};
 use ropey::Rope;
-use std::ops::Range;
-use text_indexed::OffsetToPosition;
+use std::{cmp::Ordering, ops::Range};
+
+///
+pub type Offset = usize;
+/// Range of offset
+pub type OffsetRange = Range<Offset>;
+/// Range of line column
+pub type PositionRange = Range<Position>;
 
 /// A combo of [`TextMap`] + [`TextAdapter`]. Wraps the original text and
 /// provides all the conversion methods.
@@ -52,7 +57,7 @@ pub struct TextIndex {
 /// change was made is affected. Symbols and diagnostic for other lines won't be
 /// invalidated.
 #[derive(Debug, Clone, Copy, PartialEq, Eq, Hash)]
-pub struct LineColumn {
+pub struct Position {
     /// 0-indexed line inside the text document.
     pub line: u32,
     /// 0-indexed byte offset from the beginning of the.
@@ -64,10 +69,12 @@ pub struct LineColumn {
 ///
 /// Can be converted to and from [`lsp_types::TextDocumentContentChangeEvent`] by
 /// [`TextAdapter`].
+#[derive(Debug)]
 pub struct TextChange {
-    /// Specifies the part of the text that needs to be replaced. When `None` the
-    /// whole text needs to be replaced.
-    pub range: Option<Range<LineColumn>>,
+    /// Specifies the part of the text that needs to be replaced.
+    ///
+    /// When `None` the whole text needs to be replaced.
+    pub range: Option<PositionRange>,
     /// The replacement text.
     pub patch: String,
 }
